@@ -54,8 +54,8 @@ const TQString AuthDialogImpl::Username()const
 const TQString AuthDialogImpl::Password()
 {
 #if 0
-    /* as described in interface description wie must make a copy of string */
-    curPass = TQString::fromUtf8(m_PasswordEdit->password());
+    /* as described in interface description we must make a copy of string */
+    curPass = m_PasswordEdit->password();
     return curPass;
 #endif
     return m_PasswordEdit->text();
