@@ -20,9 +20,9 @@
 #ifndef HELPERSCACHEENTRY_H
 #define HELPERSCACHEENTRY_H
 
-#include "svnqttypes.hpp"
-#include "shared_pointer.hpp"
-#include "status.hpp"
+#include "svnqttypes.h"
+#include "shared_pointer.h"
+#include "status.h"
 
 // std::map 'cause TQMap isn't usable
 #include <map>
