@@ -37,7 +37,7 @@ FillCacheThread::FillCacheThread(TQObject*_parent,const TQString&reposRoot)
     m_CurrentContext = new svn::Context();
 
     m_SvnContextListener = new ThreadContextListener(m_Parent);
-    TQObject::connect(m_SvnContextListener,TQT_SIGNAL(sendNotify(const TQString&)),m_Parent,TQT_SLOT(slotNotifyMessage(const TQString&)));
+    TQObject::connect(m_SvnContextListener,TQ_SIGNAL(sendNotify(const TQString&)),m_Parent,TQ_SLOT(slotNotifyMessage(const TQString&)));
 
     m_CurrentContext->setListener(m_SvnContextListener);
     m_what = reposRoot;
