@@ -29,7 +29,7 @@
 #include <kpushbutton.h>
 #include <tdeglobal.h>
 #include <tdelocale.h>
-#include <kapp.h>
+#include <tdeapplication.h>
 #include <tdeconfigbase.h>
 #include <tdeconfig.h>
 #include <ktabwidget.h>
