@@ -40,7 +40,7 @@
 
 #include <tdeapplication.h>
 #include <kdebug.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 #include <tdemessagebox.h>
 #include <kinstance.h>
 #include <tdeglobal.h>
