@@ -41,7 +41,7 @@
 #include <kbugreport.h>
 #include <kxmlguifactory.h>
 #include <tdeaboutapplication.h>
-#include <kapp.h>
+#include <tdeapplication.h>
 #include <tdeconfigdialog.h>
 #include <tdeaboutdata.h>
 #include <tdelocale.h>
