@@ -51,7 +51,7 @@ class KProgress;
  */
 class tdesvnView : public TQWidget,public svn::repository::RepositoryListener
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /**
